summaryrefslogtreecommitdiffstats
path: root/src/sigtool.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sigtool.h')
-rw-r--r--src/sigtool.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/sigtool.h b/src/sigtool.h
index bb5da38..df35641 100644
--- a/src/sigtool.h
+++ b/src/sigtool.h
@@ -9,13 +9,13 @@
#include <config.h>
#endif
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
class KPrinter;
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQLineEdit;
class TQComboBox;
@@ -23,8 +23,8 @@ class TQCheckBox;
class TQListBox;
class TQPushButton;
class TQLabel;
-class KProcess;
-class KConfig;
+class TDEProcess;
+class TDEConfig;
class KURLRequester;
@@ -67,14 +67,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- //void saveProperties(KConfig *);
+ //void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- //void readProperties(KConfig *);
+ //void readProperties(TDEConfig *);
private slots:
@@ -101,8 +101,8 @@ private:
//SigtoolView *m_view;
/* KPrinter *m_printer;
- KToggleAction *m_toolbarAction;
- KToggleAction *m_statusbarAction;*/
+ TDEToggleAction *m_toolbarAction;
+ TDEToggleAction *m_statusbarAction;*/
signals:
@@ -125,9 +125,9 @@ private:
TQListBox *resultbox;
TQPushButton *search_button, *manual_button;
TQLabel *status_label, *matches_label;
- KProcess *childproc;
+ TDEProcess *childproc;
TQString buf;
- KConfig *config;
+ TDEConfig *config;
TQStringList lastSearchItems;
TQStringList lastSearchPaths;
TQComboBox *check_combo;
@@ -67,14 +67,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties